@@ -12,7 +12,7 @@ class additional_medicare_tax(Variable):
     )
 
     def formula(tax_unit, period, parameters):
-        amc = parameters(period).irs.payroll.medicare.additional
+        amc = parameters(period).gov.irs.payroll.medicare.additional
         # Wage and self-employment income are taxed the same.
         ELEMENTS = ["employment_income", "taxable_self_employment_income"]
         wages_plus_se = add(tax_unit, period, ELEMENTS)
